"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("../");
describe('GraphQL-Type-Query', () => {
    it('render GraphQL - basic', () => {
        const query = new __1.Query('langs', [
            {
                name: 'idLang',
                resolve: __1.types.string,
            },
            {
                name: 'name',
                resolve: __1.types.string,
            },
            {
                name: 'localName',
                resolve: __1.types.string,
            },
        ]);
        const columns = [
            'idLang',
            'name',
            'localName',
        ];
        const queryString = query.toString({ columns });
        expect(queryString).toEqual('query langs{langs{idLang name localName}}');
    });
    it('render GraphQL - variable', () => {
        const query = new __1.Query('user', [
            {
                name: 'idUser',
                resolve: __1.types.number,
            },
            {
                name: 'name',
                resolve: __1.types.string,
            },
            {
                name: 'email',
                resolve: __1.types.string,
            },
        ], {
            idUser: 'Int',
        });
        const columns = [
            'idUser',
            'name',
            'email',
        ];
        const queryString = query.toString({ columns, variables: ['idUser'] });
        expect(queryString).toEqual('query user($idUser:Int){user(idUser:$idUser){idUser name email}}');
    });
    it('render GraphQL - variable  in subqueries', () => {
        const columnsText = [
            {
                name: 'idLang',
                resolve: __1.types.string,
            },
            {
                name: 'text',
                resolve: __1.types.string,
            },
            {
                name: 'idLangText',
                resolve: __1.types.number,
            },
            {
                name: 'idTranslation',
                resolve: __1.types.number,
            },
        ];
        const query = new __1.Query('translation', [
            {
                name: 'idTranslation',
                resolve: __1.types.number,
            },
            {
                name: 'code',
                resolve: __1.types.string,
            },
            {
                name: 'text',
                resolve: (args) => {
                    const graphQL = new __1.GraphQL(columnsText, { idLang: __1.types.string });
                    return graphQL.resolve(args);
                },
            },
        ], {
            idLang: 'String',
            idTranslation: 'Int',
        });
        const queryString = query.toString({ columns: [
                'idTranslation',
                {
                    text: {
                        columns: ['idLangText', 'text'],
                        variables: ['idLang'],
                    },
                },
            ], variables: ['idTranslation'] });
        expect(queryString).toEqual('query translation($idLang:String,$idTranslation:Int){translation(idTranslation:$idTranslation){idTranslation text(idLang:$idLang){idLangText text}}}');
    });
    it('properly errors on invalid input', () => {
        const query = new __1.Query('user', [{
                name: 'idUser',
                resolve: __1.types.number,
            }]);
        expect(() => query.toString({ columns: ['idUser'], variables: ['noVariable'] })).toThrow();
        expect(() => query.toString({ columns: ['NoColumn'] })).toThrow();
    });
});
//# sourceMappingURL=Query.js.map